%bcond_with bootstrap

# build with boost
%bcond_without boost

# always extract lib majors before updating because they will change every time:
# grep -E -r 'SOVERSION\s+[0-9]+' BUILD/poppler-*/
%define cppmajor 0
%define glibmajor 8
%define qt5major 1
%define qt6major 3
%define major 126

%define girmajor 0.18

%define libname		%mklibname %{name} %{major}
%define libnameglib	%mklibname %{name}-glib %{glibmajor}
%define libnameqt5	%mklibname %{name}-qt5_ %{qt5major}
%define libnameqt6	%mklibname %{name}-qt6_ %{qt6major}
%define libnamecpp	%mklibname %{name}-cpp %{cppmajor}
%define libnamedev	%mklibname -d %{name}
%define libnameglibdev	%mklibname -d %{name}-glib
%define libnameqt5dev	%mklibname -d %{name}-qt5
%define libnameqt6dev   %mklibname -d %{name}-qt6
%define libnamecppdev   %mklibname -d %{name}-cpp
%define libnamegir	%mklibname %{name}-gir %{girmajor}

Name:		poppler
Summary: 	PDF rendering library
Group:		Publishing
Version:	23.02.0
%define subrel 2
Release:	%mkrel 1
License:	GPLv2+
URL:		https://poppler.freedesktop.org
Source:		https://poppler.freedesktop.org/%{name}-%{version}.tar.xz
Patch0:		poppler-23.02.0-force-font-name.patch
Patch1:		poppler-23.02.0-OutlineItem-crash.patch
Patch2:		poppler-CVE-2024-4141.patch
BuildRequires:	pkgconfig(cairo)
BuildRequires:	pkgconfig(cairo-ft)
BuildRequires:	pkgconfig(cairo-pdf)
BuildRequires:	pkgconfig(cairo-ps)
BuildRequires:	pkgconfig(cairo-svg)
BuildRequires:	pkgconfig(fontconfig)
BuildRequires:	pkgconfig(freetype2)
%if ! %{with bootstrap}
BuildRequires:	pkgconfig(gdk-pixbuf-2.0)
BuildRequires:	pkgconfig(gio-2.0)
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(gobject-2.0)
BuildRequires:	pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  gtk-doc
BuildRequires:	python3
%endif
BuildRequires:	pkgconfig(lcms2)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(nss)
%if ! %{with bootstrap}
# Qt5
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Test)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	pkgconfig(Qt5Xml)
# Qt6
BuildRequires:	qtbase6-qtpaths
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Test)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(Qt6Xml)
%endif
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libopenjp2)
BuildRequires:	pkgconfig(poppler-data)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:	gettext-devel
BuildRequires:	cmake
BuildRequires:	ninja
%if %{with boost}
BuildRequires:  boost-devel
%endif
Provides:	xpdf-tools
Provides:	pdftohtml

%description
Poppler is a PDF rendering library based on the xpdf-3.0 code base.

%package -n	%{libname}
Summary:	PDF rendering library
Group:          System/Libraries
Recommends:	poppler-data

%description -n	%{libname}
Poppler is a PDF rendering library based on the xpdf-3.0 code base.

%package -n	%{libnamedev}
Summary:	Development files for %{name}
Group:		Development/C++
Provides:	%{name}-devel = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
%if %{with boost}
# /usr/include/poppler/splash/SplashXPathScanner.h:31:10: fatal error:
# boost/container/small_vector.hpp: No such file or directory
Requires:	boost-devel
%endif

%description -n	%{libnamedev}
Development files for %{name}

%package -n	%{libnamecpp}
Summary:	PDF rendering library - C++ backend
Group:          System/Libraries

%description -n	%{libnamecpp}
Poppler is a PDF rendering library based on the xpdf-3.0 code base.
This is the C++ backend version.

%package -n	%{libnameqt5dev}
Summary: 	Development files for %{name}-qt5
Group:		Development/KDE and Qt
Provides:	%{name}-qt5-devel = %{version}-%{release}
Requires:	%{libnameqt5} = %{version}-%{release}
Requires:	%{libnamedev} = %{version}-%{release}

%description -n	%{libnameqt5dev}
Development files for %{name}-qt5.

%package -n	%{libnameqt5}
Summary: 	PDF rendering library - Qt5 backend
Group:		System/Libraries

%description -n	%{libnameqt5}
Poppler is a PDF rendering library based on the xpdf-3.0 code base.
This is the Qt5 backend version.

%package -n     %{libnameqt6dev}
Summary:        Development files for %{name}-qt6
Group:          Development/KDE and Qt
Provides:	%{name}-qt6-devel = %{version}-%{release}
Requires:	%{libnameqt6} = %{version}-%{release}
Requires:	%{libnamedev} = %{version}-%{release}

%description -n %{libnameqt6dev}
Development files for %{name}-qt6.

%package -n     %{libnameqt6}
Summary:        PDF rendering library - Qt6 backend
Group:          System/Libraries

%description -n %{libnameqt6}
Poppler is a PDF rendering library based on the xpdf-3.0 code base.
This is the Qt6 backend version.

%package -n	%{libnameglib}
Summary:	PDF rendering library - glib binding
Group:		System/Libraries

%description -n	%{libnameglib}
Poppler is a PDF rendering library based on the xpdf-3.0 code base.

%package -n	%{libnamegir}
Summary:	Gobject-introspection files for %{name}
Group:		System/Libraries
Requires:	%{libnameglib} = %{version}-%{release}

%description -n	%{libnamegir}
Gobject-introspection files for %{name}.

%package -n	%{libnameglibdev}
Summary:	Development files for %{name}'s glib binding
Group:		Development/C++
Provides:	%{name}-glib-devel = %{version}-%{release}
Requires:	%{libnameglib} = %{version}-%{release}
%if ! %{with bootstrap}
Requires:	%{libnamegir} = %{version}-%{release}
%endif
Requires:	%{libnamedev} = %{version}-%{release}

%description -n	%{libnameglibdev}
Development files for %{name}'s glib binding.

%package -n	%{libnamecppdev}
Summary:	Development files for %{name}-cpp
Group:		Development/C++
Provides:	%{name}-cpp-devel = %{version}-%{release}
Requires:	%{libnamecpp} = %{version}-%{release}
Requires:	%{libnamedev} = %{version}-%{release}

%description -n	%{libnamecppdev}
Development files for %{name}-cpp.

%prep
%setup -q
%autopatch -p1

%build
%if ! %{with bootstrap}
export MOCQT5=%{_qt5_bindir}/moc
export MOCQT6=%{_qt6_bindir}/moc
%endif

%cmake -GNinja \
  -DBUILD_GTK_TESTS=%{?with_bootstrap:OFF}%{!?with_bootstrap:ON} \
  -DBUILD_QT5_TESTS=%{?with_bootstrap:OFF}%{!?with_bootstrap:ON} \
  -DBUILD_QT6_TESTS=%{?with_bootstrap:OFF}%{!?with_bootstrap:ON} \
  -DENABLE_CMS=lcms2 \
  -DENABLE_DCTDECODER=libjpeg \
  -DENABLE_LIBOPENJPEG=openjpeg2 \
  -DENABLE_QT5=%{?with_bootstrap:OFF}%{!?with_bootstrap:ON} \
  -DENABLE_QT6=%{?with_bootstrap:OFF}%{!?with_bootstrap:ON} \
  -DENABLE_UNSTABLE_API_ABI_HEADERS=ON \
  -DENABLE_GTK_DOC=%{?with_bootstrap:OFF}%{!?with_bootstrap:ON}

%cmake_build

%install
%cmake_install

cp -a %{_vpath_builddir}/config.h %{buildroot}%{_includedir}/poppler/

%files
%license COPYING
%doc AUTHORS NEWS README.md
%{_bindir}/*
%{_mandir}/man1/*

%files -n %{libname}
%{_libdir}/libpoppler.so.%{major}{,.*}

%files -n %{libnamedev}
%{_libdir}/libpoppler.so
%dir %{_includedir}/poppler/
%{_includedir}/poppler/config.h
%{_includedir}/poppler/[A-Z]*
%{_includedir}/poppler/fofi
%{_includedir}/poppler/goo
%{_includedir}/poppler/splash
%{_includedir}/poppler/poppler_private_export.h
%{_includedir}/poppler/poppler-config.h
%{_libdir}/pkgconfig/poppler.pc
%if ! %{with bootstrap}
%doc %{_datadir}/gtk-doc/html/%{name}/
%endif

%files -n %{libnameglib}
%{_libdir}/libpoppler-glib.so.%{glibmajor}{,.*}

%if ! %{with bootstrap}
%files -n %{libnamegir}
%{_libdir}/girepository-1.0/Poppler-%{girmajor}.typelib
%endif

%files -n %{libnameglibdev}
%{_libdir}/libpoppler-glib.so
%{_libdir}/pkgconfig/poppler-glib.pc
%{_includedir}/poppler/glib/
%if ! %{with bootstrap}
%{_datadir}/gir-1.0/Poppler-%{girmajor}.gir
%endif

%if ! %{with bootstrap}
%files -n %{libnameqt5dev}
%{_includedir}/poppler/qt5/
%{_libdir}/pkgconfig/poppler-qt5.pc
%{_libdir}/libpoppler-qt5.so

%files -n %{libnameqt5}
%{_libdir}/libpoppler-qt5.so.%{qt5major}{,.*}

%files -n %{libnameqt6dev}
%{_includedir}/poppler/qt6/
%{_libdir}/pkgconfig/poppler-qt6.pc
%{_libdir}/libpoppler-qt6.so

%files -n %{libnameqt6}
%{_libdir}/libpoppler-qt6.so.%{qt6major}{,.*}
%endif

%files -n %{libnamecpp}
%{_libdir}/libpoppler-cpp.so.%{cppmajor}{,.*}

%files -n %{libnamecppdev}
%{_libdir}/libpoppler-cpp.so
%{_libdir}/pkgconfig/poppler-cpp.pc
%{_includedir}/poppler/cpp


%changelog
* Thu Jun 13 2024 ns80 <ns80> 23.02.0-1.2.mga9
+ Revision: 2072988
- add a patch from openSUSE for CVE-2024-4141 (mga#33298)
- add patches from Fedora to fix crashes and CVE-2023-34872 (mga#32600)

* Sun Feb 12 2023 wally <wally> 23.02.0-1.mga9
+ Revision: 1940940
- new version 23.02.0

* Sat Jan 14 2023 wally <wally> 23.01.0-1.mga9
+ Revision: 1933144
- new version 23.01.0

* Mon Dec 12 2022 ns80 <ns80> 22.12.0-2.mga9
+ Revision: 1921134
- rebuild for new libtiff

* Sat Dec 03 2022 wally <wally> 22.12.0-1.mga9
+ Revision: 1915995
- new version 22.12.0
- new lib major 126

* Mon Oct 24 2022 ghibo <ghibo> 22.10.0-1.mga9
+ Revision: 1899107
- Update to release 22.10.
- Update major to 125.

* Sat Sep 03 2022 wally <wally> 22.09.0-1.mga9
+ Revision: 1883615
- new version 22.09.0
- new lib major 124

* Sat Jul 23 2022 wally <wally> 22.07.0-1.mga9
+ Revision: 1870359
- new version 22.07.0
- new lib major 122

* Sun May 15 2022 wally <wally> 22.05.0-1.mga9
+ Revision: 1858251
- new version 22.05.0
- new lib major 121

* Sun May 01 2022 wally <wally> 22.04.0-1.mga9
+ Revision: 1855333
- new version 22.04.0
- new lib major 120
- enable Qt6 support

* Sat Mar 19 2022 tv <tv> 22.01.0-1.mga9
+ Revision: 1801105
- Update to 22.01.0 for evince-42.1
- Major is now 117
  (when upstream will ever lean about versioning symbols???)

* Sat Dec 18 2021 wally <wally> 21.12.0-1.mga9
+ Revision: 1762443
- new version 21.12.0
- new lib major 116

* Sun Nov 07 2021 wally <wally> 21.11.0-1.mga9
+ Revision: 1754521
- new version 21.11.0
- new lib major 115

* Thu Sep 09 2021 wally <wally> 21.09.0-2.mga9
+ Revision: 1744625
- rebuild for boost 1.77.0

* Tue Sep 07 2021 wally <wally> 21.09.0-1.mga9
+ Revision: 1744427
- new version 21.09.0
- new lib major 113

* Thu Aug 12 2021 wally <wally> 21.08.0-2.mga9
+ Revision: 1741199
- rebuild for poppler 21.08.0

* Thu Aug 12 2021 wally <wally> 21.08.0-1.mga9
+ Revision: 1741192
- new version 21.08.0
- new libmajor 112

* Sun Aug 08 2021 luigiwalser <luigiwalser> 21.07.0-1.mga9
+ Revision: 1740277
- 21.07.0

* Sat Jun 19 2021 wally <wally> 21.06.1-1.mga9
+ Revision: 1731278
- new version 21.06.1
- new lib major 111

* Sat Mar 20 2021 wally <wally> 21.03.0-1.mga9
+ Revision: 1705843
- new version 21.03.0
- new lib major 108

* Tue Dec 29 2020 wally <wally> 20.12.1-1.mga8
+ Revision: 1664837
- new version 20.12.1

* Thu Dec 17 2020 umeabot <umeabot> 20.12.0-2.mga8
+ Revision: 1659437
- Rebuild for new Qt5

* Sun Dec 06 2020 wally <wally> 20.12.0-1.mga8
+ Revision: 1653277
- new version 20.12.0
- new lib major 105
- drop old conflicts / obsoletes

* Sat Sep 05 2020 wally <wally> 20.09.0-1.mga8
+ Revision: 1622463
- new version 20.09.0

* Thu Aug 06 2020 wally <wally> 20.08.0-1.mga8
+ Revision: 1611559
- new version 20.08.0
- new lib major 102

* Sat May 02 2020 wally <wally> 0.88.0-2.mga8
+ Revision: 1577956
- rebuild for new boost 1.73.0

* Sat May 02 2020 wally <wally> 0.88.0-1.mga8
+ Revision: 1577882
- new version 0.88.0
- new lib major 99
- drop explicit nss/nspr reqs
+ joequant <joequant>
- put in requires that avoids pulling in firefox

* Sat Apr 04 2020 wally <wally> 0.87.0-1.mga8
+ Revision: 1564369
- new version 0.87.0
- new lib major 98

* Tue Mar 03 2020 wally <wally> 0.86.1-1.mga8
+ Revision: 1553520
- new version 0.86.1
- new lib major 97

* Sun Mar 01 2020 wally <wally> 0.86.0-1.mga8
+ Revision: 1552743
- new version 0.86.0
- new lib major 96

* Wed Feb 19 2020 umeabot <umeabot> 0.84.0-2.mga8
+ Revision: 1543950
- Mageia 8 Mass Rebuild

* Thu Jan 23 2020 wally <wally> 0.84.0-1.mga8
+ Revision: 1482539
- new version 0.84.0
- new lib major 94
- build with new cmake macros

* Fri Dec 20 2019 wally <wally> 0.83.0-1.mga8
+ Revision: 1469192
- new version 0.83.0
- new lib major 93

* Wed Oct 30 2019 wally <wally> 0.82.0-1.mga8
+ Revision: 1456840
- new version 0.82.0
- new lib major 92

* Wed Oct 09 2019 wally <wally> 0.81.0-1.mga8
+ Revision: 1450873
- new version 0.81.0
- new lib major 91
- drop old obsoletes

* Thu Sep 19 2019 wally <wally> 0.80.0-2.mga8
+ Revision: 1443924
- make devel pkg to require boost-devel

* Sun Sep 15 2019 wally <wally> 0.80.0-1.mga8
+ Revision: 1441595
- new version 0.80.0
- new lib major 90

* Fri Sep 13 2019 ns80 <ns80> 0.79.0-2.mga8
+ Revision: 1440212
- add patch for CVE-2019-10871 (mga#25432)

* Sat Jul 20 2019 wally <wally> 0.79.0-1.mga8
+ Revision: 1423101
- new version 0.79.0

* Sat Jul 13 2019 wally <wally> 0.78.0-1.mga8
+ Revision: 1421005
- new version 0.78.0
- new major 89
- drop upstreamed patches

* Mon Apr 01 2019 umeabot <umeabot> 0.74.0-3.mga7
+ Revision: 1384055
- Qt5 Rebuild

* Wed Mar 20 2019 ns80 <ns80> 0.74.0-2.mga7
+ Revision: 1379251
- add patches for CVE-2018-20662 and CVE-2019-9200 (mga#24495)

* Mon Feb 18 2019 wally <wally> 0.74.0-1.mga7
+ Revision: 1368126
- new version 0.74.0
- new main lib major 85

* Tue Feb 12 2019 luigiwalser <luigiwalser> 0.73.0-2.mga7
+ Revision: 1365403
- add upstream patch to fix CVE-2019-7310

* Sat Jan 26 2019 wally <wally> 0.73.0-1.mga7
+ Revision: 1361094
- new version 0.73.0
- new lib major 84

* Sat Dec 08 2018 wally <wally> 0.72.0-1.mga7
+ Revision: 1338974
- new version 0.72.0
- new lib major 83
- drop upstreamed patches

* Thu Nov 22 2018 ns80 <ns80> 0.71.0-2.mga7
+ Revision: 1333221
- add patches for CVE-2018-16646, CVE-2018-1905[89], CVE-2018-19060 (mga#23865)

* Sat Nov 17 2018 wally <wally> 0.71.0-1.mga7
+ Revision: 1330431
- new version 0.71.0
- new core lib major 82

* Wed Oct 31 2018 wally <wally> 0.70.1-1.mga7
+ Revision: 1326982
- new version 0.70.1
- new libpoppler major 81
- drop old obsoletes

* Mon Aug 27 2018 ns80 <ns80> 0.63.0-4.mga7
+ Revision: 1254896
- add patch for CVE-2018-13988 (mga#23383)

* Tue Jun 19 2018 ns80 <ns80> 0.63.0-3.mga7
+ Revision: 1238052
- add upstream patch for CVE-2017-18267 (mga#23138)

* Sun Apr 15 2018 daviddavid <daviddavid> 0.63.0-2.mga7
+ Revision: 1219107
- drop Qt4 support (removed upstream)
- fix some cmake options
- add libcurl support
- do a non bootstrap build

* Sun Apr 15 2018 kekepower <kekepower> 0.63.0-1.mga7
+ Revision: 1219049
- Update to version 0.63.0
- Remove upstream patches
- Bump popler major
- bootstrap

* Fri Jan 12 2018 ns80 <ns80> 0.61.1-3.mga7
+ Revision: 1192458
- add three upstream patches to fix abort on malformed documents

* Thu Jan 11 2018 ns80 <ns80> 0.61.1-2.mga7
+ Revision: 1192224
- add two upstream patches to fix a memory leak and a crash with malformed PDF files

* Tue Jan 09 2018 ns80 <ns80> 0.61.1-1.mga7
+ Revision: 1191813
- new version 0.61.1 that fixes CVE-2017-1000456 (mga#22352)

* Sat Nov 04 2017 ns80 <ns80> 0.60.1-2.mga7
+ Revision: 1175856
- add patch for CVE-2017-15565 (mga#21939)

* Wed Oct 11 2017 ns80 <ns80> 0.60.1-1.mga7
+ Revision: 1170911
- new version 0.60.1

* Wed Oct 11 2017 ns80 <ns80> 0.59.0-3.mga7
+ Revision: 1170908
- add patches for several CVEs (mga#21825)

* Wed Oct 04 2017 ns80 <ns80> 0.59.0-2.mga7
+ Revision: 1168242
- add patches for CVE-2017-14517, CVE-2017-14519 and CVE-2017-14520 (mga#21784)

* Wed Sep 13 2017 tv <tv> 0.59.0-1.mga7
+ Revision: 1153477
- new release
- new release

* Mon Jul 17 2017 tv <tv> 0.56.0-1.mga7
+ Revision: 1124111
- new release

* Fri Jul 07 2017 luigiwalser <luigiwalser> 0.52.0-3.mga6
+ Revision: 1109450
- add upstream patches to fix CVE-2017-940[68] and CVE-2017-7515
- add patch from ubuntu to fix CVE-2017-9775

* Wed Jun 07 2017 luigiwalser <luigiwalser> 0.52.0-2.mga6
+ Revision: 1107167
- add upstream patch to fix CVE-2017-7511

* Wed May 17 2017 luigiwalser <luigiwalser> 0.52.0-1.mga6
+ Revision: 1102281
- 0.52.0

* Sun Jan 01 2017 luigiwalser <luigiwalser> 0.50.0-1.mga6
+ Revision: 1078934
- 0.50.0
- library major is now 66
- build with openjpeg2 instead of openjpeg1

* Mon Nov 28 2016 luigiwalser <luigiwalser> 0.49.0-1.mga6
+ Revision: 1070582
- 0.49.0
- library major is now 65
- 0.48.0
- library major is now 64

* Sat Sep 10 2016 luigiwalser <luigiwalser> 0.47.0-1.mga6
+ Revision: 1051352
- 0.47.0

* Fri Aug 12 2016 luigiwalser <luigiwalser> 0.46.0-1.mga6
+ Revision: 1046116
- 0.46.0
- library major is now 63

* Thu Jul 07 2016 daviddavid <daviddavid> 0.44.0-2.mga6
+ Revision: 1039445
- explicitly set which openjpeg should be used, otherwise it will not found in configure

* Wed May 25 2016 luigiwalser <luigiwalser> 0.44.0-1.mga6
+ Revision: 1018547
- 0.44.0
- library major is now 61

* Mon May 09 2016 luigiwalser <luigiwalser> 0.43.0-1.mga6
+ Revision: 1011727
- 0.43.0
- library major is now 60

* Mon Jan 25 2016 luigiwalser <luigiwalser> 0.40.0-1.mga6
+ Revision: 927192
- 0.40.0

* Fri Jan 01 2016 luigiwalser <luigiwalser> 0.39.0-1.mga6
+ Revision: 917604
- 0.39.0
- library major is now 58

* Tue Aug 25 2015 pterjan <pterjan> 0.34.0-2.mga6
+ Revision: 869220
- Rebuild with gcc 5

* Sat Jul 25 2015 tv <tv> 0.34.0-1.mga6
+ Revision: 857522
- new release

* Mon Jun 29 2015 wally <wally> 0.33.0-2.mga6
+ Revision: 847814
- add requires for gir pkg to devel pkg

* Sun Jun 21 2015 ovitters <ovitters> 0.33.0-1.mga6
+ Revision: 837843
- new version 0.33.0

* Wed Oct 15 2014 umeabot <umeabot> 0.26.5-2.mga5
+ Revision: 748668
- Second Mageia 5 Mass Rebuild

* Tue Oct 14 2014 luigiwalser <luigiwalser> 0.26.5-1.mga5
+ Revision: 738661
- 0.26.5

* Fri Sep 26 2014 wally <wally> 0.26.4-3.mga5
+ Revision: 724954
- rebuild with new rpm-mageia-setup to generate requires for .typelib files

* Tue Sep 16 2014 umeabot <umeabot> 0.26.4-2.mga5
+ Revision: 687720
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Sat Aug 23 2014 luigiwalser <luigiwalser> 0.26.4-1.mga5
+ Revision: 666918
- 0.26.4

* Thu Jul 24 2014 luigiwalser <luigiwalser> 0.26.3-1.mga5
+ Revision: 656180
- 0.26.3

* Tue Jun 24 2014 luigiwalser <luigiwalser> 0.26.2-1.mga5
+ Revision: 639126
- 0.26.2

* Mon May 26 2014 luigiwalser <luigiwalser> 0.26.1-1.mga5
+ Revision: 626554
- 0.26.1

* Sat Apr 26 2014 luigiwalser <luigiwalser> 0.26.0-1.mga5
+ Revision: 618334
- 0.26.0
- library major is now 46
- remove qt5 moc patch (fixed upstream)

* Thu Feb 06 2014 fwang <fwang> 0.24.5-1.mga5
+ Revision: 584618
- bump lib major
- 0.24.5

* Tue Jan 07 2014 luigiwalser <luigiwalser> 0.24.3-2.mga4
+ Revision: 565460
- add patch from fedora to fix crasher DoS issue (kde#328511)

* Wed Oct 30 2013 oden <oden> 0.24.3-1.mga4
+ Revision: 547918
- 0.24.3 (fixes CVE-2013-4474)

* Mon Oct 21 2013 colin <colin> 0.24.2-2.mga4
+ Revision: 539678
- Fix Qt5 moc check
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Sat Sep 28 2013 luigiwalser <luigiwalser> 0.24.2-1.mga4
+ Revision: 488433
- 0.24.2

* Thu Aug 29 2013 sander85 <sander85> 0.24.1-1.mga4
+ Revision: 473046
- New version: 0.24.1

* Wed Jul 31 2013 fwang <fwang> 0.24.0-1.mga4
+ Revision: 461343
- bump libmajor
- disable test prog
+ ovitters <ovitters>
- new version 0.24.0

* Sat Jul 20 2013 fwang <fwang> 0.23.4-1.mga4
+ Revision: 456501
- add qt5 lib
- update libmajor
- tweak openjpeg br
- new version 0.23.4

* Mon Jun 17 2013 fwang <fwang> 0.22.5-1.mga4
+ Revision: 444053
- new version 0.22.5
- rebuild for new openjpeg

* Sun Jun 02 2013 fwang <fwang> 0.22.4-2.mga4
+ Revision: 434606
- rebuild for new libpng

* Fri May 24 2013 fwang <fwang> 0.22.4-1.mga4
+ Revision: 425814
- update libmajor
- new version 0.22.4

* Sun Feb 24 2013 luigiwalser <luigiwalser> 0.22.1-1.mga3
+ Revision: 400211
- 0.22.1

* Sun Jan 13 2013 umeabot <umeabot> 0.22.0-2.mga3
+ Revision: 378052
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 30 2012 fwang <fwang> 0.22.0-1.mga3
+ Revision: 336397
- update libmajor
- new version 0.22.0

* Mon Nov 12 2012 fwang <fwang> 0.21.1-1.mga3
+ Revision: 317109
- update libmajor
- new version 0.21.1

* Wed Oct 10 2012 tv <tv> 0.21.0-1.mga3
+ Revision: 304159
- new release (fix gnome#617946)

* Sun Oct 07 2012 fwang <fwang> 0.20.4-2.mga3
+ Revision: 303248
- update rpm group
- rebuild for new openjpeg

* Tue Sep 11 2012 blino <blino> 0.20.4-1.mga3
+ Revision: 292112
- 0.20.4

* Sun Aug 19 2012 luigiwalser <luigiwalser> 0.20.3-1.mga3
+ Revision: 282379
- 0.20.3
- remove upstream patches

* Sun Jul 22 2012 blino <blino> 0.20.2-2.mga3
+ Revision: 273563
- sync patches from poppler-0.20 git branch (to fix division by zero, fdo #52215)

* Thu Jul 12 2012 fwang <fwang> 0.20.2-1.mga3
+ Revision: 270145
- new version 0.20.2

* Wed Jun 13 2012 fwang <fwang> 0.20.1-3.mga3
+ Revision: 260241
- correct poppler-qt4 libname

* Wed Jun 13 2012 fwang <fwang> 0.20.1-2.mga3
+ Revision: 260181
- use lcms2

* Mon Jun 11 2012 vaci0 <vaci0> 0.20.1-1.mga3
+ Revision: 259886
- Update to 0.20.1

* Thu Apr 12 2012 fwang <fwang> 0.18.4-2.mga2
+ Revision: 230355
- rebuild for new openjpeg

* Fri Feb 17 2012 fwang <fwang> 0.18.4-1.mga2
+ Revision: 210041
- new version 0.18.4

* Sun Jan 22 2012 fwang <fwang> 0.18.3-1.mga2
+ Revision: 199554
- new version 0.18.3

* Fri Dec 23 2011 fwang <fwang> 0.18.2-2.mga2
+ Revision: 186472
- rebuild for new libtiff

* Wed Dec 07 2011 fwang <fwang> 0.18.2-1.mga2
+ Revision: 178134
- new version 0.18.2

* Fri Oct 28 2011 fwang <fwang> 0.18.1-1.mga2
+ Revision: 158949
- br gettext-devel
- fix pkgconfig file of poppler-glib
- do not promote qt4 path now
- update major
- drop deprecated symbol of glib 2.31
- drop old switch
- new version 0.18.1

* Fri Oct 07 2011 fwang <fwang> 0.18.0-3.mga2
+ Revision: 152633
- force build with openjpeg

* Fri Oct 07 2011 fwang <fwang> 0.18.0-2.mga2
+ Revision: 152611
- rebuild for new openjpeg

* Tue Sep 27 2011 ovitters <ovitters> 0.18.0-1.mga2
+ Revision: 149334
- new version 0.18.0

* Sat Sep 10 2011 fwang <fwang> 0.16.7-3.mga2
+ Revision: 142216
- do not ship .la files
- rebuild for new libpng
+ ze <ze>
- fix provides
- arranhe spec

* Sat Jul 16 2011 ahmad <ahmad> 0.16.7-2.mga2
+ Revision: 124675
- Drop the Qt3 bits, Qt3 has been dead for some time now
- The gir package should require %%libnameglib, not the other way around
- Convert the BR to pkgconfig style
- -devel packages now only provide %%{name}-*-devel

* Mon Jul 04 2011 ahmad <ahmad> 0.16.7-1.mga2
+ Revision: 118007
- Update to 0.16.7
- Add (optional) BR lcms-devel

* Mon Jun 13 2011 ahmad <ahmad> 0.16.6-1.mga2
+ Revision: 105874
- Update to 0.16.6
- libify the gir typelib sub-package

* Thu May 12 2011 pterjan <pterjan> 0.16.5-1.mga1
+ Revision: 97383
- Update to 0.16.5 (bugfix release)

* Mon Apr 04 2011 ahmad <ahmad> 0.16.4-1.mga1
+ Revision: 80490
- update to 0.16.4
- move %%_datadir/gir-1.0/Poppler-%%{girmajor}.gir to %%{libnameglib} (Fedora)
- make the gir sub-package require %%{libnameglib}
- make the glib lib sub-package require %%{namegir} >= %%{version}
- split Poppler-*.typelib in a separate package to ease poppler major updates

* Mon Mar 28 2011 blino <blino> 0.16.3-3.mga1
+ Revision: 78257
- add back conflicts, needed because of girepository-1.0/Poppler-0.16.typelib

* Mon Mar 28 2011 tv <tv> 0.16.3-2.mga1
+ Revision: 78239
- cleanup: remove bogus conflicts that defeats libification purpose

* Sat Mar 26 2011 pterjan <pterjan> 0.16.3-1.mga1
+ Revision: 77778
- Update to 0.16.3

* Sat Jan 15 2011 ahmad <ahmad> 0.16.0-2.mga1
+ Revision: 19344
- drop old/uneeded macros
- disable qt3support
- drop an old conflict with xpdf
- imported package poppler


* Thu Dec 30 2010 Götz Waschk <waschk@mandriva.org> 0.16.0-1mdv2011.0
+ Revision: 626088
- new version
- new major numbers
- enable introspection

* Mon Nov 08 2010 Götz Waschk <waschk@mandriva.org> 0.14.5-1mdv2011.0
+ Revision: 595097
- update to new version 0.14.5

* Wed Nov 03 2010 Götz Waschk <waschk@mandriva.org> 0.14.4-2mdv2011.0
+ Revision: 592855
- fix conflict to make glib devel package installable

* Thu Oct 14 2010 Götz Waschk <waschk@mandriva.org> 0.14.4-1mdv2011.0
+ Revision: 585596
- update to new version 0.14.4

* Sat Sep 11 2010 Funda Wang <fwang@mandriva.org> 0.14.3-1mdv2011.0
+ Revision: 577579
- update to new version 0.14.3

* Sun Aug 22 2010 Funda Wang <fwang@mandriva.org> 0.14.2-1mdv2011.0
+ Revision: 571790
- New version 0.14.2

* Thu Aug 05 2010 Götz Waschk <waschk@mandriva.org> 0.14.1-1mdv2011.0
+ Revision: 566130
- new version
- drop patch 0 (not needed anymore according to Fedora)
- fix build
- new version
- new major
- add poppler-cpp
- drop patches 2,4

  + Funda Wang <fwang@mandriva.org>
    - we are using standard qt dir, so no need to tweak configure

* Sun Jun 06 2010 Colin Guthrie <cguthrie@mandriva.org> 0.12.4-2mdv2010.1
+ Revision: 547156
- Bump release to ensure version is > 2010.0 update version

* Thu Feb 18 2010 Götz Waschk <waschk@mandriva.org> 0.12.4-1mdv2010.1
+ Revision: 507684
- new version
- drop patch 3

* Wed Jan 27 2010 Frederic Crozat <fcrozat@mandriva.com> 0.12.3-6mdv2010.1
+ Revision: 497255
- Patch4 (Carlos): fix rotation (fdo #26264)

* Wed Jan 27 2010 Frederic Crozat <fcrozat@mandriva.com> 0.12.3-5mdv2010.1
+ Revision: 497092
- Patch3 (GIT): fix mask (fdo bug #16906)

* Fri Jan 22 2010 Frederic Crozat <fcrozat@mandriva.com> 0.12.3-4mdv2010.1
+ Revision: 494982
- New version for patch2

* Fri Jan 15 2010 Frederic Crozat <fcrozat@mandriva.com> 0.12.3-3mdv2010.1
+ Revision: 491777
- Patch2 (Huug):  improve cairo prescaling (fdo #5589)

* Sun Jan 10 2010 Oden Eriksson <oeriksson@mandriva.com> 0.12.3-2mdv2010.1
+ Revision: 488795
- rebuilt against libjpeg v8

* Sat Dec 26 2009 Frederik Himpe <fhimpe@mandriva.org> 0.12.3-1mdv2010.1
+ Revision: 482370
- update to new version 0.12.3

* Tue Dec 22 2009 Funda Wang <fwang@mandriva.org> 0.12.2-2mdv2010.1
+ Revision: 481221
- use openjpeg for jpeg2000

* Thu Nov 19 2009 Oden Eriksson <oeriksson@mandriva.com> 0.12.2-1mdv2010.1
+ Revision: 467454
- 0.12.2

* Thu Oct 22 2009 Frederic Crozat <fcrozat@mandriva.com> 0.12.1-2mdv2010.0
+ Revision: 458892
- Force rebuild

  + Oden Eriksson <oeriksson@mandriva.com>
    - 0.12.1
    - new ObjStream patch (fedora)
    - rediffed the CVE-2009-3608 CVE-2009-3609 patch

* Sat Oct 17 2009 Paulo Andrade <pcpa@mandriva.com.br> 0.12.0-3mdv2010.0
+ Revision: 457970
- Correct CVE-2009-3608 and CVE-2009-3609

* Sun Oct 11 2009 Olivier Blin <oblin@mandriva.com> 0.12.0-2mdv2010.0
+ Revision: 456647
- fix group

* Thu Sep 10 2009 Frederik Himpe <fhimpe@mandriva.org> 0.12.0-1mdv2010.0
+ Revision: 437102
- Update to new verison 0.12.0
- Remove string format patch: not needed anymore

* Wed Aug 19 2009 Frederik Himpe <fhimpe@mandriva.org> 0.11.3-1mdv2010.0
+ Revision: 417957
- update to new version 0.11.3

* Sat Aug 15 2009 Oden Eriksson <oeriksson@mandriva.com> 0.11.2-2mdv2010.0
+ Revision: 416530
- rebuilt against libjpeg v7

* Tue Aug 04 2009 Frederik Himpe <fhimpe@mandriva.org> 0.11.2-1mdv2010.0
+ Revision: 409399
- Update to new version 0.11.2

* Fri Jul 10 2009 Götz Waschk <waschk@mandriva.org> 0.11.1-1mdv2010.0
+ Revision: 394162
- new version
- update file list
- rediff patch 1

* Tue May 19 2009 Götz Waschk <waschk@mandriva.org> 0.11.0-1mdv2010.0
+ Revision: 377467
- new version, needed by evince 2.27
- bump deps
- new major
- update file list

* Sun May 17 2009 Funda Wang <fwang@mandriva.org> 0.10.7-1mdv2010.0
+ Revision: 376734
- New version 0.10.7

* Fri Apr 17 2009 Frederic Crozat <fcrozat@mandriva.com> 0.10.6-1mdv2009.1
+ Revision: 367901
- Remove patch0 (useless)
- Merge patch 1 and 3 and remove most unneeeded changes and error in it

  + Rafael da Veiga Cabral <cabral@mandriva.com>
    - This version update provides security fixes for CVE-2009-0799,
      CVE-2009-0800, CVE-2009-1179, CVE-2009-1180, CVE-2009-1181,
      CVE-2009-1182, CVE-2009-1183, CVE-2009-1187 and CVE-2009-1188
      and other bug fixes
    - poppler-0.8.7-qt3-configure.patch rediff

* Sun Mar 15 2009 Götz Waschk <waschk@mandriva.org> 0.10.5-1mdv2009.1
+ Revision: 355261
- update to new version 0.10.5

* Wed Feb 11 2009 Götz Waschk <waschk@mandriva.org> 0.10.4-1mdv2009.1
+ Revision: 339448
- update to new version 0.10.4

* Fri Jan 23 2009 Jérôme Soyer <saispo@mandriva.org> 0.10.3-2mdv2009.1
+ Revision: 333149
- Fix qt3 build and add patch for str format
- Add patch for ObjStream

* Sun Jan 11 2009 Funda Wang <fwang@mandriva.org> 0.10.3-1mdv2009.1
+ Revision: 328164
- New version 0.10.3

* Fri Dec 26 2008 Funda Wang <fwang@mandriva.org> 0.10.2-1mdv2009.1
+ Revision: 319271
- New version 0.10.2
- fix str fmt

* Tue Nov 11 2008 Götz Waschk <waschk@mandriva.org> 0.10.1-1mdv2009.1
+ Revision: 302103
- update to new version 0.10.1

* Fri Nov 07 2008 Götz Waschk <waschk@mandriva.org> 0.10.0-2mdv2009.1
+ Revision: 300761
- rebuild for new libxcb

* Sat Oct 11 2008 Götz Waschk <waschk@mandriva.org> 0.10.0-1mdv2009.1
+ Revision: 292463
- new version
- new majors

* Tue Sep 23 2008 Helio Chissini de Castro <helio@mandriva.com> 0.8.7-2mdv2009.0
+ Revision: 287631
- Renable qt3 support in poppler by fixing compilation against as-needed

* Tue Sep 02 2008 Helio Chissini de Castro <helio@mandriva.com> 0.8.7-1mdv2009.0
+ Revision: 279064
- New upstream regression fix version

* Thu Aug 21 2008 Helio Chissini de Castro <helio@mandriva.com> 0.8.6-2mdv2009.0
+ Revision: 274459
- Finally build against jpeg

* Wed Aug 20 2008 Helio Chissini de Castro <helio@mandriva.com> 0.8.6-1mdv2009.0
+ Revision: 274208
- New upstream version. Fix bug for evince and okular https://qa.mandriva.com/show_bug.cgi?id=42204 ( [Bug 42204] poppler, ASSIGNED: Some PDFs show corrupted colors )

* Tue Jul 29 2008 Helio Chissini de Castro <helio@mandriva.com> 0.8.5-1mdv2009.0
+ Revision: 252726
- New upstream version bugfix release.

* Fri Jul 18 2008 Götz Waschk <waschk@mandriva.org> 0.8.4-1mdv2009.0
+ Revision: 238067
- new version
- drop patch 1

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Tue Jun 03 2008 Helio Chissini de Castro <helio@mandriva.com> 0.8.3-1mdv2009.0
+ Revision: 214845
- New upstream 0.8.3
- Disable ( finally ) qt3 support. Now qt4 is default

* Wed Apr 30 2008 Götz Waschk <waschk@mandriva.org> 0.8.2-1mdv2009.0
+ Revision: 199614
- new version

  + Helio Chissini de Castro <helio@mandriva.com>
    - New upstream minor release
    - Update for latest stable revision. Required by kdegraphica 4.0.68

* Wed Mar 19 2008 Frederic Crozat <fcrozat@mandriva.com> 0.6.4-2mdv2008.1
+ Revision: 188831
- poppler package now obsoletes / provides xpdf-tools

* Sat Jan 26 2008 Helio Chissini de Castro <helio@mandriva.com> 0.6.4-1mdv2008.1
+ Revision: 158290
- Update for new upstream minor version

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Thu Dec 13 2007 Helio Chissini de Castro <helio@mandriva.com> 0.6.3-1mdv2008.1
+ Revision: 119382
- New upstream version 0.6.3

  + Thierry Vignaud <tv@mandriva.org>
    - do not package big ChangeLog

* Tue Nov 20 2007 Pascal Terjan <pterjan@mandriva.org> 0.6.2-2mdv2008.1
+ Revision: 110785
- Fix update from 2006.0 (#35652)

* Sat Nov 10 2007 Funda Wang <fwang@mandriva.org> 0.6.2-1mdv2008.1
+ Revision: 107459
- comment out patch that seems merged upstream
- New version 0.6.2

* Sat Oct 13 2007 Funda Wang <fwang@mandriva.org> 0.6.1-1mdv2008.0
+ Revision: 97843
- New version 0.6.1

* Wed Sep 19 2007 Guillaume Rousse <guillomovitch@mandriva.org> 0.6-3mdv2008.0
+ Revision: 90166
- rebuild

* Sun Sep 09 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 0.6-2mdv2008.0
+ Revision: 83504
- fix provides on poppler-glib-devel

* Tue Sep 04 2007 Götz Waschk <waschk@mandriva.org> 0.6-1mdv2008.0
+ Revision: 79036
- new version

  + Pascal Terjan <pterjan@mandriva.org>
    - Update major
    - 0.6

* Mon Aug 20 2007 Funda Wang <fwang@mandriva.org> 0.5.91-2mdv2008.0
+ Revision: 67320
- suggests poppler-data (bug#26509)

* Wed Aug 15 2007 Funda Wang <fwang@mandriva.org> 0.5.91-1mdv2008.0
+ Revision: 63607
- New devel package policy
- New version 0.5.91

* Tue Aug 14 2007 Pascal Terjan <pterjan@mandriva.org> 0.5.9-4mdv2008.0
+ Revision: 63404
- Add P2 for CVE 2007-3387 (#32248)

* Sat Aug 04 2007 David Walluck <walluck@mandriva.org> 0.5.9-3mdv2008.0
+ Revision: 58856
- include config.h since it is included by many headers

* Sat Jun 23 2007 Götz Waschk <waschk@mandriva.org> 0.5.9-2mdv2008.0
+ Revision: 43474
- split out glib binding

* Tue Jun 19 2007 Götz Waschk <waschk@mandriva.org> 0.5.9-1mdv2008.0
+ Revision: 41327
- new version
- drop patches 2,3
- update file list

* Tue Apr 24 2007 Pascal Terjan <pterjan@mandriva.org> 0.5.4-4mdv2008.0
+ Revision: 17819
- Obsoletes/Provides pdftohtml


* Mon Jan 22 2007 Laurent Montel <lmontel@mandriva.com> 0.5.4-3mdv2007.0
+ Revision: 111975
- Fix pedantic

* Thu Jan 18 2007 Götz Waschk <waschk@mandriva.org> 0.5.4-2mdv2007.1
+ Revision: 110462
- P2: security fix for CVE-2007-0104 (embedded xpdf)
- Import poppler

* Wed Oct 11 2006 Götz Waschk <waschk@mandriva.org> 0.5.4-1mdv2007.1
- update file list
- New version 0.5.4

* Sun Aug 20 2006 Pascal Terjan <pterjan@mandriva.org> 0.5.3-5mdv2007.0
- Avoid some crash (P0, P1, bug #24515)

* Tue Jul 04 2006 Pascal Terjan <pterjan@mandriva.org> 0.5.3-4mdv2007.0
- Fix group of -devel subpackages

* Sat Jun 24 2006 Laurent MONTEL <lmontel@mandriva.com> 0.5.3-3
- Rebuild

* Thu Jun 01 2006 Götz Waschk <waschk@mandriva.org> 0.5.3-2mdv2007.0
- move the headers to the right subpackage

* Thu Jun 01 2006 Pascal Terjan <pterjan@mandriva.org> 0.5.3-1mdv2007.0
- New release 0.5.3
- enable qt4

* Wed May 24 2006 Götz Waschk <waschk@mandriva.org> 0.5.2-1mdk
- disable qt4
- New release 0.5.2

* Wed May 03 2006 Laurent MONTEL <lmontel@mandriva.com> 0.5.1-7
- Disable qt4 support as poppler developper was not able to create good makefile... => link by default qt support with qt4 lib is not a very good idea...

* Wed Apr 26 2006 Götz Waschk <waschk@mandriva.org> 0.5.1-6mdk
- readd xpdf headers (needed by abiword)

* Sat Apr 22 2006 Laurent MONTEL <lmontel@mandriva.com> 0.5.1-5
- Oops forgot to add ldconfig

* Sat Apr 22 2006 Laurent MONTEL <lmontel@mandriva.com> 0.5.1-4
- Fix search qt4 include/lib
- Active qt4 poppler module
- For me it will better to rename poppler-qt1 package to poppler-qt3-1- package

* Fri Apr 21 2006 Götz Waschk <waschk@mandriva.org> 0.5.1-3mdk
- fix the conflict

* Tue Mar 07 2006 Götz Waschk <waschk@mandriva.org> 0.5.1-2mdk
- fix major

* Tue Mar 07 2006 Laurent MONTEL <lmontel@mandriva.com> 0.5.1-1
- 0.5.1

* Mon Jan 23 2006 Götz Waschk <waschk@mandriva.org> 0.5.0-1mdk
- add binary package
- update file list
- drop patches
- New release 0.5.0

* Mon Jan 16 2006 Pascal Terjan <pterjan@mandriva.org> 0.4.4-1mdk
- 0.4.4
- Drop P1

* Fri Jan 06 2006 Pascal Terjan <pterjan@mandriva.org> 0.4.3-2mdk
- patches from MDKSA-2006:003 :
 - overflow issues discovered by Chris Evans (P1)
  (CVE-2005-3624,3625,3626,3627)
 - overflows in goo/gmem.c (P2)

* Fri Dec 30 2005 Götz Waschk <waschk@mandriva.org> 0.4.3-1mdk
- New release 0.4.3
- use mkrel

* Wed Oct 05 2005 Götz Waschk <waschk@mandriva.org> 0.4.2-1mdk
- drop patch 1
- New release 0.4.2

* Fri Sep 09 2005 Frederic Crozat <fcrozat@mandriva.com> 0.4.1-3mdk 
- Patch1 (CVS): various fixes, fixes zlib compression pdf, rotations
  freetype2 usage

* Sun Aug 28 2005 Götz Waschk <waschk@mandriva.org> 0.4.1-2mdk
- remove fortiy from optflags
- cjk patch, thanks to Pablo Rodriguez

* Sat Aug 27 2005 Götz Waschk <waschk@mandriva.org> 0.4.1-1mdk
- New release 0.4.1

* Wed Aug 17 2005 Götz Waschk <waschk@mandriva.org> 0.4.0-1mdk
- New release 0.4.0

* Fri Aug 12 2005 Götz Waschk <waschk@mandriva.org> 0.3.3-2mdk
- rebuild for new cairo

* Sat Jun 25 2005 Götz Waschk <waschk@mandriva.org> 0.3.3-1mdk
- New release 0.3.3

* Fri May 20 2005 Götz Waschk <waschk@mandriva.org> 0.3.2-1mdk
- requires new cairo
- drop merged patch
- New release 0.3.2

* Fri May 06 2005 Pascal Terjan <pterjan@mandriva.org> 0.3.1-4mdk
- Enforce Qt suuport so that we fail at configure not when checking %%files
- Fix building Qt support on x86_64

* Thu May 05 2005 Laurent MONTEL <lmontel@mandriva.com> 0.3.1-3mdk
- Rebuild with new gcc
- Add patch1: fix load text in utf8 Patch from Albert Astals Cid

* Tue May 03 2005 Götz Waschk <waschk@mandriva.org> 0.3.1-2mdk
- move qt support to a separate package

* Tue May 03 2005 Laurent MONTEL <lmontel@mandriva.com> 0.3.1-1mdk
- 0.3.1
- Reactivate qt support necessary for kat

* Sun Apr 24 2005 Götz Waschk <waschk@mandriva.org> 0.3.0-1mdk
- disable qt wrapper
- New release 0.3.0

* Tue Apr 19 2005 Götz Waschk <waschk@linux-mandrake.com> 0.2.0-2mdk
- enable cairo

* Thu Apr 07 2005 Götz Waschk <waschk@linux-mandrake.com> 0.2.0-1mdk
- New release 0.2.0

* Tue Mar 15 2005 Pascal Terjan <pterjan@mandrake.org> 0.1.2-2mdk
- Explicitely disable cairo and drop the useless BuildRequires (will have
  to be when we'll have newer cairo)

* Mon Mar 14 2005 Pascal Terjan <pterjan@mandrake.org> 0.1.2-1mdk
- First mdk package

